pub fn emit_message(
w: &mut CodeWriter,
msg: &MessageDef,
registry: &TypeRegistry,
needs_box: &HashSet<(TypeId, usize)>,
type_id: TypeId,
)Expand description
Emit a complete message struct with Pack and Unpack implementations.
pub fn emit_message(
w: &mut CodeWriter,
msg: &MessageDef,
registry: &TypeRegistry,
needs_box: &HashSet<(TypeId, usize)>,
type_id: TypeId,
)Emit a complete message struct with Pack and Unpack implementations.